@@ -43,9 +43,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <kinputdialog.h>
 #include <kio/netaccess.h>
 #include <kmenubar.h>
-#include <kmountpoint.h>
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <kprotocolmanager.h>
 #include <kstatusbar.h>
 #include <ktogglefullscreenaction.h>
 #include <ktoolbar.h>
@@ -77,6 +77,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include <lib/sorteddirmodel.h>
 #include <lib/thumbnailview.h>
 #include <lib/transformimageoperation.h>
+#include <lib/urlutils.h>
 
 namespace Gwenview {
 
@@ -100,10 +101,7 @@ static bool urlIsDirectory(QWidget* parent, const KUrl& url) {
 	}
 
 	// Do direct stat instead of using KIO if the file is local (faster)
-	KMountPoint::List mpl = KMountPoint::currentMountPoints();
-	KMountPoint::Ptr mp = mpl.findByPath( url.path() );
-
-	if( url.isLocalFile() && !mp->probablySlow()) {
+	if (UrlUtils::urlIsFastLocalFile(url)) {
 		KDE_struct_stat buff;
 		if ( KDE_stat( QFile::encodeName(url.path()), &buff ) == 0 )  {
 			return S_ISDIR( buff.st_mode );
@@ -208,7 +206,7 @@ struct MainWindow::Private {
 		mThumbnailView->setThumbnailViewHelper(mThumbnailViewHelper);
 		mThumbnailView->setSelectionMode(QAbstractItemView::ExtendedSelection);
 		connect(mThumbnailView, SIGNAL(indexActivated(const QModelIndex&)),
-			mWindow, SLOT(openDirUrlFromIndex(const QModelIndex&)) );
+			mWindow, SLOT(slotThumbnailViewIndexActivated(const QModelIndex&)) );
 		connect(mThumbnailView->selectionModel(), SIGNAL(selectionChanged(const QItemSelection&, const QItemSelection&)),
 			mWindow, SLOT(slotSelectionChanged()) );
 
@@ -699,7 +697,15 @@ void MainWindow::setActiveViewModeAction(QAction* action) {
 	d->mDocumentView->setVisible(showDocument);
 	if (showDocument && d->mDocumentView->isEmpty()) {
 		openSelectedDocument();
-	} else if (!showDocument && !d->mDocumentView->isEmpty()) {
+	} else if (!showDocument
+		&& !d->mDocumentView->isEmpty()
+		&& KProtocolManager::supportsListing(d->mDocumentView->url()))
+	{
+		// Reset the view to spare resources, but don't do it if we can't
+		// browse the url, otherwise if the user starts Gwenview this way:
+		// gwenview http://example.com/example.png
+		// and switch to browse mode, switching back to view mode won't bring
+		// his image back.
 		d->mDocumentView->reset();
 	}
 	d->mThumbnailViewPanel->setVisible(showThumbnail);
@@ -712,7 +718,7 @@ void MainWindow::setActiveViewModeAction(QAction* action) {
 }
 
 
-void MainWindow::openDirUrlFromIndex(const QModelIndex& index) {
+void MainWindow::slotThumbnailViewIndexActivated(const QModelIndex& index) {
 	if (!index.isValid()) {
 		return;
 	}
@@ -725,6 +731,8 @@ void MainWindow::openDirUrlFromIndex(const QModelIndex& index) {
 		QString protocol = ArchiveUtils::protocolForMimeType(item.mimetype());
 		url.setProtocol(protocol);
 		openDirUrl(url);
+	} else {
+		d->mViewAction->trigger();
 	}
 }
 
@@ -804,6 +812,10 @@ void MainWindow::updateContextManager() {
 void MainWindow::slotPartCompleted() {
 	Q_ASSERT(!d->mDocumentView->isEmpty());
 	KUrl url = d->mDocumentView->url();
+	if (!KProtocolManager::supportsListing(url)) {
+		return;
+	}
+
 	KUrl dirUrl = url;
 	dirUrl.setFileName("");
 	if (dirUrl.equals(d->mDirModel->dirLister()->url(), KUrl::CompareWithoutTrailingSlash)) {
@@ -1002,6 +1014,21 @@ void MainWindow::saveAs(const KUrl& url) {
 		return;
 	}
 
+	// Check for overwrite
+	if (KIO::NetAccess::exists(dialog.selectedUrl(), KIO::NetAccess::DestinationSide, this)) {
+		int answer = KMessageBox::warningContinueCancel(
+			this,
+			i18nc("@info",
+				"A file named <filename>%1</filename> already exists.\n"
+				"Are you sure you want to overwrite it?",
+				dialog.selectedUrl().fileName()),
+			QString(),
+			KStandardGuiItem::overwrite());
+		if (answer == KMessageBox::Cancel) {
+			return;
+		}
+	}
+
 	// Start save
 	mimeType = dialog.currentMimeFilter();
 	QStringList typeList = KImageIO::typeForMime(mimeType);
@@ -1214,6 +1241,10 @@ void MainWindow::loadConfig() {
 	d->mDocumentView->setPalette(palette);
 
 	d->mThumbnailSlider->setValue(GwenviewConfig::thumbnailSize());
+	// If GwenviewConfig::thumbnailSize() returns the current value of
+	// mThumbnailSlider, it won't emit valueChanged() and the thumbnail view
+	// won't be updated. That's why we do it ourself.
+	d->mThumbnailView->setThumbnailSize(GwenviewConfig::thumbnailSize());
 }
 
 
