@@ -85,7 +85,7 @@
 #include "core/fileprinter.h"
 
 K_PLUGIN_FACTORY( okularPartFactory, registerPlugin< Part >(); )
-K_EXPORT_PLUGIN( okularPartFactory( okularAboutData( "okular", I18N_NOOP( "okular" ) ) ) )
+K_EXPORT_PLUGIN( okularPartFactory( okularAboutData( "okular", I18N_NOOP( "Okular" ) ) ) )
 
 static QAction* actionForExportFormat( const Okular::ExportFormat& format, QObject *parent = 0 )
 {
@@ -282,6 +282,9 @@ m_cliPresentation(false), m_generatorGuiClient(0)
     m_document->addObserver( m_pageSizeLabel );
     m_document->addObserver( bookmarkList );
 
+    connect( m_document->bookmarkManager(), SIGNAL( saved() ),
+        this, SLOT( slotRebuildBookmarkMenu() ) );
+
     // ACTIONS
     KActionCollection * ac = actionCollection();
 
@@ -573,13 +576,20 @@ void Part::setMimeTypes(KIO::Job *job)
 void Part::loadCancelled(const QString &reason)
 {
     emit setWindowCaption( QString() );
-    if (!reason.isEmpty())
+
+    // when m_viewportDirty.pageNumber != -1 we come from slotDoFileDirty
+    // so we don't want to show an ugly messagebox just because the document is
+    // taking more than usual to be recreated
+    if (m_viewportDirty.pageNumber == -1)
     {
-        KMessageBox::error( widget(), i18n("Could not open %1. Reason: %2", url().prettyUrl(), reason ) );
-    }
-    else
-    {
-        KMessageBox::error( widget(), i18n("Could not open %1", url().prettyUrl() ) );
+        if (!reason.isEmpty())
+        {
+            KMessageBox::error( widget(), i18n("Could not open %1. Reason: %2", url().prettyUrl(), reason ) );
+        }
+        else
+        {
+            KMessageBox::error( widget(), i18n("Could not open %1", url().prettyUrl() ) );
+        }
     }
 }
 
@@ -1026,6 +1036,10 @@ void Part::enableTOC(bool enable)
     m_sidebar->setItemEnabled(0, enable);
 }
 
+void Part::slotRebuildBookmarkMenu()
+{
+    rebuildBookmarkMenu();
+}
 
 void Part::slotShowFindBar()
 {
@@ -1058,6 +1072,7 @@ class GotoPageDialog : public KDialog
             e1 = new KIntNumInput(current, w);
             e1->setRange(1, max);
             e1->setEditFocus(true);
+            e1->setSliderEnabled(true);
 
             QLabel *label = new QLabel(i18n("&Page:"), w);
             label->setBuddy(e1);
@@ -1215,7 +1230,7 @@ void Part::slotSaveFileAs()
                 return;
         }
 
-        KIO::Job *copyJob = KIO::file_copy( url(), saveUrl, -1, KIO::Overwrite );
+        KIO::Job *copyJob = KIO::file_copy( localFilePath(), saveUrl, -1, KIO::Overwrite );
         if ( !KIO::NetAccess::synchronousRun( copyJob, widget() ) )
             KMessageBox::information( widget(), i18n("File could not be saved in '%1'. Try to save it to another location.", saveUrl.prettyUrl() ) );
     }
@@ -1562,7 +1577,7 @@ void Part::setupPrint( QPrinter &printer )
         page = m_document->page(i);
         width = page->width();
         height = page->height();
-        if (page->orientation() == 90 || page->orientation() == 270) qSwap(width, height);
+        if (page->orientation() == Okular::Rotation90 || page->orientation() == Okular::Rotation270) qSwap(width, height);
         if (width > height) landscape++;
         else portrait++;
     }
