@@ -18,6 +18,8 @@
 #include <qlabel.h>
 #include <qlineedit.h>
 #include <qpainter.h>
+#include <qstyle.h>
+#include <qstyleoption.h>
 #include <qtooltip.h>
 #include <qvalidator.h>
 #include <qapplication.h>
@@ -298,14 +300,14 @@ void PresentationWidget::wheelEvent( QWheelEvent * e )
         if ( div > 3 )
             div = 3;
         while ( div-- )
-            slotNextPage();
+            slotPrevPage();
     }
     else if ( div < 0 )
     {
         if ( div < -3 )
             div = -3;
         while ( div++ )
-            slotPrevPage();
+            slotNextPage();
     }
 }
 
@@ -435,7 +437,9 @@ void PresentationWidget::paintEvent( QPaintEvent * pe )
         sp.setHorizontalPolicy( QSizePolicy::Minimum );
         m_pagesEdit->setSizePolicy( sp );
         QFontMetrics fm( m_pagesEdit->font() );
-        m_pagesEdit->setMaximumWidth( fm.width( QString::number( m_document->pages() ) ) * 2 );
+        QStyleOptionFrame option;
+        option.initFrom(m_pagesEdit);
+        m_pagesEdit->setMaximumWidth( fm.width( QString::number( m_document->pages() ) ) + 2 * style()->pixelMetric(QStyle::PM_DefaultFrameWidth, &option, m_pagesEdit) + 4 ); // the 4 comes from 2*horizontalMargin, horizontalMargin being a define in qlineedit.cpp
         QIntValidator *validator = new QIntValidator( 1, m_document->pages(), m_pagesEdit );
         m_pagesEdit->setValidator( validator );
         m_topBar->addWidget( m_pagesEdit );
